1.0.0 API documentation: GLM_EXT_scalar_int_sized

| 1.0.0 API documentation

Typedefs
GLM_EXT_scalar_int_sized
Stable extensions

## Typedefs
typedef detail::int16 | int16
| 16 bit signed integer type.
typedef detail::int32 | int32
| 32 bit signed integer type.
typedef detail::int64 | int64
| 64 bit signed integer type.
typedef detail::int8 | int8
| 8 bit signed integer type.

## Detailed Description

Exposes sized signed integer scalar types.

Include <glm/ext/scalar_int_sized.hpp> to use the features of this extension.

See also
  GLM_EXT_scalar_uint_sized